@@ -1267,7 +1267,7 @@ on_atomixed_manual_activate            (GtkMenuItem     *menuitem,
 	{
 		gchar *url;
 		
-		url = g_strconcat("file:", helpfile, NULL);
+		url = g_strconcat("ghelp:", helpfile, NULL);
 		
 		gnome_help_goto(NULL, url);
 		
